%% calc_IDD_plane: Calculate the IDD plane normal
% 
% Arguments:
% 	ca_pdb_struct_obj: PDB structure object containing only C-alpha atoms. Type: 1xN struct
% 
% Returns:
% 	IDD_norm: Vector that is orthonormal to the IDD plane. Type: 3x1 double
% 	mean_mid_point_transitions: Mean of the mid-point of the transition points. Type: 3x1 double
% 	num_transition_points: Number of transition points. Type: double
function [IDD_norm, mean_mid_point_transitions, num_transition_points] = calc_IDD_plane(ca_pdb_struct_obj)

	% For each chain, identify transition points and the midpoint of these transition points
	chains = separatePDBByChain(ca_pdb_struct_obj);
	transition_mid_points = [];

	for chain_idx=1:length(chains)
		current_chain = chains{chain_idx};

		eigvec_elem = [current_chain.eigvec_elem];
		transition_idx_start = find(eigvec_elem(2:end) - eigvec_elem(1:end-1));
		transition_idx_end = transition_idx_start + 1;
		transition_mid_points = [transition_mid_points (([current_chain(transition_idx_start).coord] + [current_chain(transition_idx_end).coord])/2)];
	end

	eigvec_elem = [ca_pdb_struct_obj.eigvec_elem]';
	positive_obj = ca_pdb_struct_obj(eigvec_elem);
	negative_obj = ca_pdb_struct_obj(~eigvec_elem);
	num_transition_points = size(transition_mid_points, 2);

	% >0 transition points, take the mean of the mid point of these transition points 
	if num_transition_points > 0
		mean_mid_point_transitions = mean(transition_mid_points, 2);

	% Otherwise, find the positive-negative pair with the shortest distance and calculate mid point 
	else
		pairwise_dist_mat = getPairwiseDistance(positive_obj, negative_obj);
		[max_vals, arg_max_vals] = max(pairwise_dist_mat);
		[~, pos_idx] = max(max_vals);
		neg_idx = arg_max_vals(pos_idx);

		mean_mid_point_transitions = ((positive_obj(pos_idx).coord + negative_obj(neg_idx).coord)/2);
	end

	% Find the LDA plane normal that best separates the positive and negative atoms
	IDD_norm = LDA([positive_obj.coord], [negative_obj.coord]);
end