%% parse_FTDock_output: Parse the output of FTDock
% 
% The coordinates here must be from the 2 files of the protein and DNA submitted to FTDock for docking and
% translated such that their their center of geometry is at origin
% 
% Arguments:
% 	FTDock_output_file: Full path to the FTDock output file. Type: Char
% 	prot_coord_origin: Coordinates of protein atoms whose the center of geometry is at origin. Type: 3xN double
% 	DNA_coord_origin: Coordinates of DNA atoms whose the center of geometry is at origin. Type: 3xN double
% 	num_conformers: The number of top conformers to be parsed and returned. If the number of conformers is more
% 		than all conformers in FTDock_output_file, warning will be given and all conformers will be returned.
% 		Type: int32
% 
% Returns:
% 	trans_rot_data: Translation rotation data of the top num_conformers. The 6 columns are:
% 		Translation: x, y ,z
% 		Angles: z_twist, theta, phi (Z-Y-Z Euler angles)
% 	Type: num_conformersx6 double
function [trans_rot_data] = parse_FTDock_output(FTDock_output_file, prot_coord_origin, DNA_coord_origin, num_conformers)
	file_str = fileread(FTDock_output_file);
	file_lines = strsplit(file_str, '\n');
	
	% Grid size data
	grid_data = strsplit(file_lines{6});
	grid_size = str2double(grid_data{5});
	grid_span = (radius(prot_coord_origin) + radius(DNA_coord_origin)) * 2 + 1;
	one_span = grid_span/grid_size;

	% Make sure that the number of conformers is less than the total number
	total_num_conformers = size(file_lines, 2) - 18;

	if total_num_conformers < num_conformers
		num_conformers = total_num_conformers;
		display(['Warning: There are only: ' num2str(num_conformers) ' conformers. Will only process the top '  num2str(num_conformers) ' conformers'])
	end

	% Translation-rotation data
	data_lines = file_lines(18:17+num_conformers);
	trans_rot_data = zeros(num_conformers,6);

	for idx = 1:num_conformers
		split_line = strsplit(data_lines{idx});
		trans_rot_data(idx,:) = [str2double(split_line(6:8))*one_span str2double(split_line(9:end))];
	end
end