%% IDD_prot_DNA_conformer_filter: Use IDD plane to filter protein-DNA conformers from FTDock
% 
% Arguments:
% 	FTDock_output_file: Full path to the FTDock output file. Type: char
% 	prot_pdb_file: Full path of the protein PDB file used as input to FTDock. Type: char
% 	dna_pdb_file: Full path of the DNA PDB file used as input to FTDock. Type: char
% 
% Optional Arguments:
% 	num_conformers: The number of top conformers to be parsed and returned. If the number of conformers is more
% 		than all conformers in FTDock_output_file, warning will be given and all conformers will be returned.
% 		If empty string will take default value. Type: int32. Default: 4000
% 	filtered_conformers_list_file: Name of tab delimited file to write filtered_conformers_list to. Type: char
% 		If not supplied or an empty string, filtered_conformers_list will not be written out to disk
% 	output_folder: Full path of the output folder used to write the filtered conformers. Type: char.
% 		If not supplied or an empty string, filtered conformers are not written out to disk
% 
% Returns:
% 	filtered_conformers_list: FTDock rank and min distance from IDD plane. Type: Nx2 double
% 	IDD_norm: Vector that is orthonormal to the IDD plane. Type: 3x1 double
% 	mean_mid_point_transitions: Mean of the mid-point of the transition points. Type: 3x1 double
% 	num_transition_points: Number of transition points. Type: int32
function [filtered_conformers_list, IDD_norm, mean_mid_point_transitions, num_transition_points] = IDD_prot_DNA_conformer_filter(FTDock_output_file, prot_pdb_file, dna_pdb_file, num_conformers, filtered_conformers_list_file, output_folder)

	if ~exist('num_conformers', 'var') || numel(num_conformers) == 0
		num_conformers = 4000;
	end

	% Read Protein PDB
	prot_struct_obj = readPDB(prot_pdb_file);
	prot_coord = [prot_struct_obj.coord];
	prot_coord = center_of_geo_to_ori(prot_coord);

	prot_struct_obj = setAttribute(prot_struct_obj,1:size(prot_coord,2),'coord',prot_coord);

	[IDD_norm, mean_mid_point_transitions, num_transition_points]=calc_IDD(prot_struct_obj);

	% Read DNA PDB
	DNA_struct_obj = readPDB(dna_pdb_file);
	DNA_coord = [DNA_struct_obj.coord];
	DNA_coord = center_of_geo_to_ori(DNA_coord);

	DNA_struct_obj = setAttribute(DNA_struct_obj,1:size(DNA_coord,2),'coord',DNA_coord);

	% Merge Protein-DNA structure
	complex_pdb_obj = mergeStructures(prot_struct_obj, DNA_struct_obj);

	% Read FTDock output
	trans_rot_data = parse_FTDock_output(FTDock_output_file, prot_coord, DNA_coord, num_conformers);
	num_conformers = size(trans_rot_data,1);

	filtered_conformers_list = zeros(num_conformers,2);
	atom_idx_range = size(prot_struct_obj,2)+1:size(complex_pdb_obj,2);
	num_filtered_conformers = 0;

	% If output_folder is defined, check if folder exist. Create folder if it doesn't exist
	if exist('output_folder', 'var') && numel(output_folder) ~= 0

		if ~isdir(output_folder)
			mkdir(output_folder);
		end
	end

	% Check distance from IDD plane and filter
	for conformer_id = 1:num_conformers
		current_DNA_conformation = trans_rot(DNA_coord, trans_rot_data(conformer_id,4), trans_rot_data(conformer_id,5), trans_rot_data(conformer_id,6), trans_rot_data(conformer_id,1:3)');
		dist = calc_min_dist_from_IDD_plane(current_DNA_conformation, IDD_norm, mean_mid_point_transitions);

		if dist <= 0.3
			num_filtered_conformers = num_filtered_conformers + 1;
			filtered_conformers_list(num_filtered_conformers,:) = [conformer_id dist];

			if exist('output_folder', 'var') && numel(output_folder) ~= 0
				complex_pdb_obj = setAttribute(complex_pdb_obj,atom_idx_range,'coord',current_DNA_conformation);
				createPDB(complex_pdb_obj, fullfile(output_folder, ['complex_' num2str(conformer_id) '.pdb']));
			end
		end
	end

	filtered_conformers_list = filtered_conformers_list(1:num_filtered_conformers,:);

	if exist('filtered_conformers_list_file', 'var') && numel(filtered_conformers_list_file) ~= 0
		write_output_to_tdfile(filtered_conformers_list_file, filtered_conformers_list);
	end
end
